import tempfile
import unittest

from antelope.datascope import dbopen, closing, freeing, Dbptr, DbsubsetError
from webservice_fdsn.app.core.event_helpers import get_event_data
from webservice_fdsn.app.core.event_exporter.export_events_helpers import exceptions as event_exceptions
from webservice_fdsn.app.core.constants.geographic_constraints import AREA_RECTANGLE_MIN_LATITUDE
from webservice_fdsn.app.core.constants.geographic_constraints import AREA_RECTANGLE_MAX_LATITUDE
from webservice_fdsn.app.core.constants.geographic_constraints import AREA_RECTANGLE_MIN_LONGITUDE
from webservice_fdsn.app.core.constants.geographic_constraints import AREA_RECTANGLE_MAX_LONGITUDE
from webservice_fdsn.app.core.constants.fdsnws_event import MIN_DEPTH, MAX_DEPTH, MIN_MAGNITUDE, MAX_MAGNITUDE,\
    ORDER_BY
from webservice_fdsn.app.core.constants.time_constraints import SIMPLE_TIME_START_TIME, SIMPLE_TIME_END_TIME


class TestEventApi(unittest.TestCase):

    def setUp(self):
        self.db_path = '/opt/antelope/data/db/demo/demo'

    def test_get_event_data(self):
        """

        :return:
        """
        data = dict()
        data[AREA_RECTANGLE_MIN_LATITUDE] = -90
        data[AREA_RECTANGLE_MAX_LATITUDE] = 90
        data[AREA_RECTANGLE_MIN_LONGITUDE] = -180
        data[AREA_RECTANGLE_MAX_LONGITUDE] = 180
        data[MIN_DEPTH] = 0
        data[MAX_DEPTH] = 50000
        data[MIN_MAGNITUDE] = 0
        data[MAX_MAGNITUDE] = 10
        data[SIMPLE_TIME_START_TIME] = 946710000.0
        data[SIMPLE_TIME_END_TIME] = 1577862000.0

        with tempfile.TemporaryDirectory() as td:
            rx_path = get_event_data.get_event_data(self.db_path, td, **data)
            self.assertIsInstance(rx_path, str)
            self.assertIn(td, rx_path)

    def test_get_event_data_unknown_event(self):
        """

        :return:
        """
        required_args = dict()
        required_args[MIN_DEPTH] = 1
        required_args[MAX_DEPTH] = 10
        required_args[MIN_MAGNITUDE] = 1
        required_args[MAX_MAGNITUDE] = 10
        required_args[AREA_RECTANGLE_MIN_LATITUDE] = 20
        required_args[AREA_RECTANGLE_MAX_LATITUDE] = 30
        required_args[AREA_RECTANGLE_MIN_LONGITUDE] = 10
        required_args[AREA_RECTANGLE_MAX_LONGITUDE] = 100
        required_args[SIMPLE_TIME_START_TIME] = 946710000.0
        required_args[SIMPLE_TIME_END_TIME] = 1577862000.0
        required_args[ORDER_BY] = 'time'
        with self.assertRaises(event_exceptions.NoEventDataFound):
            with tempfile.TemporaryDirectory() as td:
                get_event_data.get_event_data(self.db_path, td, **required_args)

    def test_apply_time_window(self):
        """

        :return:
        """
        with closing(dbopen(self.db_path, perm='r')) as db:
            dbtable = db.lookup(table='event')
            with freeing(dbtable.join('origin', outer=True)) as dbt:
                dbptr = get_event_data.apply_time_window(dbt,
                                                         1452594580.0,
                                                         1452680980.0)
            self.assertIsInstance(dbptr, Dbptr)
